@@ -53,6 +53,12 @@ def _main():
                     'message': 'Target Team Slug',
                     'default': 'fulfillment-squad-artemis'
                 },
+                {
+                    'type': 'input',
+                    'name': 'target_team_admin',
+                    'message': 'Target Team Admin Slug',
+                    'default': 'fulfillment-admins'
+                },
                 {
                     'type': 'input',
                     'name': 'prefix',
