@@ -26,7 +26,7 @@ accept_header = "application/vnd.github.mercy-preview+json"
 errors = []
 
 s = requests.Session()
-retries = Retry(total=5, backoff_factor=1, status_forcelist=[404])
+retries = Retry(total=5, backoff_factor=1, status_forcelist=[404, 422])
 s.mount('https://', HTTPAdapter(max_retries=retries))
 
 
@@ -53,6 +53,7 @@ def prompt_questions(repo, proceed_with_prompt):
         proceed_answers_ok["is_ok"] = "don't ask me again!"
         return proceed_answers_ok
 
+
 def get_team(answers_github):
     target_team_name = answers_github.get("target_team_name")
     source_org = answers_github.get("source_github_org")
@@ -91,7 +92,6 @@ def search_by_topic(topic, source_org, password, answers_github):
     separator = "+"
     search_string = separator.join(list_of_topics)
 
-
     url = f"https://api.github.com/search/repositories?q=org:{source_org} {search_string}"
 
     team_ids = get_team(answers_github)
@@ -214,47 +214,65 @@ def rename_master_to_main(repo, org, answers, headers):
         return False
 
 
-def update_webhooks(repo, org, answers, headers):
-    print("Updating Web Hooks .... ")
-
+def make_repo_internal(repo, answers, headers):
     team_prefix = answers.get("prefix")
-    ctx = ssl.create_default_context()
-    ctx.check_hostname = False
-    ctx.verify_mode=ssl.CERT_NONE
-    headers["User-Agent"] = "python"
-    conn = http.client.HTTPSConnection("api.github.com", context=ctx)
+    target_org = answers.get("target_github_org")
+    url = f"https://api.github.com/repos/{target_org}/{team_prefix}.{repo}"
 
-    url = f"/repos/{org}/{team_prefix}.{repo}/hooks"
+    private_payload = json.dumps({
+        "private": True,
+        "visibility": "internal"
+    })
 
-    payload = ''
-    conn.request("GET", url,payload,headers)
+    headers["Accept"] = "application/vnd.github.nebula-preview+json"
 
-    hooks_response = conn.getresponse()
-    data = hooks_response.read()
+    response = requests.request("PATCH", url, headers=headers, data=private_payload)
 
-    print(data.decode("utf-8"))
+    if response.status_code == 200:
+        print(f"Made {repo} internal after transfer")
 
-    if hooks_response.status == 200:
-        response_json = json.loads(data.decode("utf-8"))
 
-        for config in response_json:
-            hook_url = config.get("config").get("url")
-            hook_id = config.get("id")
-            if "bmx" in hook_url:
-                new_hook_url = f"https://github-webhooks.baat-tools-prod.nikecloud.com/v1/{hook_url}"
-                url = f"https://api.github.com/repos/{org}/{team_prefix}.{repo}/hooks/{hook_id}"
-                data = {"config": {"url": new_hook_url}}
-                response = s.patch(url, data=json.dumps(data),
-                                   headers=headers)
-                if response.status_code == 200:
-                    print("Updated Web Hooks ")
-
-            else:
-                print("no bmx repo wehbooks found")
-        return True
-    else:
-        print("no webhooks found")
-        return True
+def update_webhooks(repo, org, answers, headers):
+    # print("Updating Web Hooks .... ")
+    #
+    # team_prefix = answers.get("prefix")
+    # ctx = ssl.create_default_context()
+    # ctx.check_hostname = False
+    # ctx.verify_mode = ssl.CERT_NONE
+    # headers["User-Agent"] = "python"
+    # conn = http.client.HTTPSConnection("api.github.com", context=ctx)
+    #
+    # url = f"/repos/{org}/{team_prefix}.{repo}/hooks"
+    #
+    # payload = ''
+    # conn.request("GET", url, payload, headers)
+    #
+    # hooks_response = conn.getresponse()
+    # data = hooks_response.read()
+    #
+    # # print(data.decode("utf-8"))
+    #
+    # if hooks_response.status == 200:
+    #     response_json = json.loads(data.decode("utf-8"))
+    #
+    #     for config in response_json:
+    #         hook_url = config.get("config").get("url")
+    #         hook_id = config.get("id")
+    #         if "bmx" in hook_url:
+    #             new_hook_url = f"https://github-webhooks.baat-tools-prod.nikecloud.com/v1/{hook_url}"
+    #             url = f"https://api.github.com/repos/{org}/{team_prefix}.{repo}/hooks/{hook_id}"
+    #             data = {"config": {"url": new_hook_url}}
+    #             response = s.patch(url, data=json.dumps(data),
+    #                                headers=headers)
+    #             if response.status_code == 200:
+    #                 print("Updated Web Hooks ")
+    #
+    #         else:
+    #             print(f"not a bmx repo wehbook {hook_url}")
+    #     return True
+    # else:
+    #     print("no webhooks found")
+    return True
 
 
 def transfer_repo_to_targetorg(repo, answers, headers):
@@ -277,6 +295,49 @@ def transfer_repo_to_targetorg(repo, answers, headers):
         return False
 
 
+def make_team_admin_writers(repo, answers, headers):
+    print("changing team level access")
+    team_slug = answers.get("target_team_name")
+    team_admin_slug = answers.get("target_team_admin")
+    team_prefix = answers.get("prefix")
+
+    target_org = answers.get("target_github_org")
+
+    team_url = f"https://api.github.com/orgs/{target_org}/teams/{team_slug}"
+
+    team_resp = s.get(team_url,
+                      headers=headers)
+    parent_slug = team_prefix
+    if team_resp.status_code == 200 and "parent" in json.loads(team_resp.content.decode()) and \
+            json.loads(team_resp.content.decode())["parent"] is not None:
+        parent_slug = json.loads(team_resp.content.decode())["parent"]["slug"]
+
+    access_levels = {
+        parent_slug: "push",
+        team_slug: "maintain",
+        team_admin_slug: "admin",
+        f"{team_prefix}-external-contributors": "push"
+
+    }
+
+    for slug, access_level in access_levels.items():
+
+        team_access_url = f"https://api.github.com/orgs/{target_org}/teams/{slug}/repos/{target_org}/{team_prefix}.{repo}"
+
+        payload = json.dumps({
+            "permission": access_level
+        })
+
+        response = s.put(team_access_url, headers=headers, data=payload)
+
+        if response.status_code == 204:
+            print(f"Changed {slug} to be a {access_level}")
+        else:
+            print(response.content.decode())
+            print(f"Team access failed with error code " + str(response.status_code) + " url is " + team_access_url)
+        time.sleep(0.5)
+
+
 def transfer_repo(repo, answers, team_ids):
     print("\nTransferring " + repo + " to target organization")
     source_org = answers.get("source_github_org")
@@ -296,6 +357,8 @@ def transfer_repo(repo, answers, team_ids):
                 is_transfer_success = transfer_repo_to_targetorg(repo, answers, headers)
                 if is_transfer_success:
                     print(f"Transfer completed for repo {repo}")
+                    make_team_admin_writers(repo, answers, headers)
+                    make_repo_internal(repo, answers, headers)
                 else:
                     print(f"Transfer failed for repo {repo}")
             else:
