@@ -25,7 +25,6 @@ def get_jobs(jenkins_answers):
     old_org = jenkins_answers.get("old_org")
     new_org = jenkins_answers.get("new_org")
 
-
     api_uri = "<apiUri>https://github.nike.com/api/v3<apiUri>"
 
     server = jenkins.Jenkins(jenkins_url, username=username, password=token)
@@ -42,18 +41,18 @@ def get_jobs(jenkins_answers):
             config = config.replace("github.nike.com", "github.com")
             for org in old_org.split(","):
                 config = config.replace(org, new_org)
-            if credentialsId.strip()!="":
-                config = re.sub("<credentialsId>.*</credentialsId>", f"<credentialsId>{credentialsId}</credentialsId>", config)
+            if credentialsId.strip() != "":
+                config = re.sub("<credentialsId>.*</credentialsId>", f"<credentialsId>{credentialsId}</credentialsId>",
+                                config)
 
+            change_name = [
 
-            change_name = [{
                 {
                     'type': 'confirm',
                     'name': 'change_name',
-                    'message': f"Change the bmx job name to team_prefix.<oldname>?",
-                    'default': False
+                    'message': "Change the bmx job name to team_prefix.<oldname>?"
                 }
-            }]
+            ]
             change_name_answers = prompt(change_name, style=style)
             if change_name_answers.get("change_name"):
                 job_match = re.findall(r'<displayName>.*</displayName>', config)
@@ -86,9 +85,4 @@ def get_jobs(jenkins_answers):
                         break
                     else:
                         if answers.get("is_ok") == "don't ask me again!":
-                            is_prompt_user=False
-
-
-
-
-
+                            is_prompt_user = False
